@@ -15,7 +15,7 @@ var searchData=
   ['defined_12',['Where are the keyboard layouts defined?',['../faq.html#where-are-the-keyboard-layouts-defined',1,'']]],
   ['definitions_13',['definitions',['../keymap-text-format-v1-v2.html#key-type-statement',1,'Type definitions'],['../error-index.html#XKB-407',1,'XKB-407 – Conflicting key type definitions']]],
   ['definitions_20examples_14',['Definitions examples',['../keymap-text-format-v1-v2.html#definitions-examples',1,'']]],
-  ['deprecated_15',['Deprecated',['../release-notes.html#deprecated',1,'Deprecated'],['../release-notes.html#deprecated-1',1,'Deprecated']]],
+  ['deprecated_15',['Deprecated',['../release-notes.html#deprecated',1,'Deprecated'],['../release-notes.html#deprecated-1',1,'Deprecated'],['../release-notes.html#deprecated-2',1,'Deprecated']]],
   ['deprecated_20keysym_16',['XKB-301 – Deprecated keysym',['../error-index.html#XKB-301',1,'']]],
   ['deprecated_20keysym_20name_17',['XKB-302 – Deprecated keysym name',['../error-index.html#XKB-302',1,'']]],
   ['deprecated_20list_18',['Deprecated List',['../deprecated.html',1,'']]],
